@@ -3,7 +3,7 @@ package Locale::TextDomain::OO; ## no critic (TidyCode)
 use strict;
 use warnings;
 
-our $VERSION = '1.024';
+our $VERSION = '1.025';
 
 use Locale::TextDomain::OO::Translator;
 
@@ -36,13 +36,13 @@ __END__
 
 Locale::TextDomain::OO - Perl OO Interface to Uniforum Message Translation
 
-$Id: OO.pm 617 2015-08-22 05:39:27Z steffenw $
+$Id: OO.pm 633 2017-02-17 17:50:25Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO.pm $
 
 =head1 VERSION
 
-1.024
+1.025
 
 Starting with version 1.000 the interface has changed.
 
@@ -260,35 +260,39 @@ Run the examples of this distribution (folder example).
  | Gettext::Loc (Hint: select this) | > and < | (Hint: select this)    |
  | Gettext::Loc::DomainAndCategory  | |     | |                        |
  | (experimental)                   | |     | | Maketext::Localise     |
- | Gettext::Named (experimental)    |/       \| Maketext::Localize     |
+ | Gettext::Named (experimental)    | |     | | Maketext::Localize     |
+ | BabelFish::Loc (experimental)    |/       \|                        |
  `---------------------------------------------------------------------'
                             ^
                             |
  .--------------------------'-----------------.
- | Locale::TextDomain::OO::Singleton::Lexicon |------------------------.
- `--------------------------------------------'                        |
-                            ^                                          |
-                            |                                          |
- .--------------------------'-------------------------------.          |
- | build lexicon using Locale::TextDomain::OO::Lexicon::... |          |
- |----------------------------------------------------------|          |
- |           Hash              |   File::MO     | File::PO  |          |
- `----------------------------------------------------------'          |
-       ^               ^               ^              ^                |
-       |               |               |              |                |
- .-----'-----.    _____|_____    .-----'----.       .-----'----.       |
- | Perl      |   /_ _ _ _ _ _\   | mo files |-.     | po files |-.     |
- | data      |   |           |   `----------' |-.   `----------' |-.   |
- | structure |   | Database  |     `----------' |     `----------' |   |
- `-----------'   `-----------'       `----------'       `----------'   |
-                                       ^                   ^           |
-                                       |                   |           |
-                        build using                                    |
-                        Locale::TextDomain::OO::Extract                |
-                        and Locale::TextDomain::OO::Extract::Process   |
-                                                                       |
-                                  .------------------------------------'
-                                  |
+ | Locale::TextDomain::OO::Singleton::Lexicon |-------------------------.
+ `--------------------------------------------'                         |
+                            ^                                           |
+                            |                                           |
+ .--------------------------'-------------------------------.           |
+ | build lexicon using Locale::TextDomain::OO::Lexicon::... |           |
+ |----------------------------------------------------------|           |
+ |           Hash              |   File::PO     | File::MO  |           |
+ `----------------------------------------------------------'           |
+       ^               ^               ^                  ^             |
+       |               |               |                  |             |
+ .-----'-----.    _____|_____    .-----'----.       .-----'----.        |
+ | Perl      |   /_ _ _ _ _ _\   | po files |-.     | mo files |-.      |
+ | data      |   |           |   `----------' |-.   `----------' |-.    |
+ | structure |   | Database  |     `----------' |     `----------' |    |
+ `-----------'   `-----------'       `----------'       `----------'    |
+                                       ^  ^               ^             |
+                                       |  |               |             |
+         .-----------------------------'  |               |             |
+  _______|_______                         |               |             |
+ /_ _ _ _ _ _ _ _\   .----------------------------------------------.   |
+ | Autotranslate |   | build using PO/MO                            |   |
+ | Cache         |   | Locale::TextDomain::OO::Extract              |   |
+ | CacheDatabase |   | and Locale::TextDomain::OO::Extract::Process |   |
+ `---------------'   `----------------------------------------------'   |
+                                                                        |
+                                  .-------------------------------------'
                                   v
  .---------------------------------------------------------------------.
  | build JSON lexicon using Locale::TextDomain::OO::Lexicon::StoreJSON |
@@ -633,7 +637,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009 - 2015,
+Copyright (c) 2009 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
