@@ -10,7 +10,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.023';
 
 with qw(
     Locale::TextDomain::OO::Role::Logger
@@ -44,7 +44,7 @@ sub lexicon_ref {
             exists $value->{msgstr_plural}
                 or next VALUE;
             my $plural_count = @{ $value->{msgstr_plural} };
-            $plural_count == $nplurals or confess sprintf
+            $plural_count <= $nplurals or confess sprintf
                 'Count of msgstr_plural=%s but nplurals=%s for msgid="%s" msgid_plural="%s"',
                 $plural_count,
                 $nplurals,
@@ -73,13 +73,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::Hash - Lexicon from data structure
 
-$Id: Hash.pm 546 2014-10-31 09:35:19Z steffenw $
+$Id: Hash.pm 618 2015-08-22 18:02:42Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/Hash.pm $
 
 =head1 VERSION
 
-1.014
+1.023
 
 =head1 DESCRIPTION
 
@@ -227,7 +227,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013 - 2014,
+Copyright (c) 2013 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
